=== modified file 'bzr'
--- bzr	2005-08-25 07:46:11 +0000
+++ bzr	2005-09-09 14:17:50 +0000
@@ -40,7 +40,8 @@
     print >>sys.stderr, "bzr: error: cannot find a suitable python interpreter"
     print >>sys.stderr, "  (need %d.%d or later)" % NEED_VERS
     sys.exit(1)
-os.unsetenv(REINVOKE)
+if hasattr(os, "unsetenv"):
+    os.unsetenv(REINVOKE)
 
 import bzrlib
 import bzrlib.commands

=== modified file 'bzr-man.py'
--- bzr-man.py	2005-06-06 13:24:18 +0000
+++ bzr-man.py	2005-09-09 14:17:50 +0000
@@ -42,7 +42,8 @@
     print >>sys.stderr, "bzr-man.py: error: cannot find a suitable python interpreter"
     print >>sys.stderr, "  (need %d.%d or later)" % NEED_VERS
     sys.exit(1)
-os.unsetenv(REINVOKE)
+if hasattr(os, "unsetenv"):
+    os.unsetenv(REINVOKE)
 
 import bzrlib, bzrlib.help
 

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2005-09-01 11:19:08 +0000
+++ bzrlib/osutils.py	2005-09-09 14:17:50 +0000
@@ -407,21 +407,27 @@
     """Return size of given open file."""
     return os.fstat(f.fileno())[ST_SIZE]
 
-
-if hasattr(os, 'urandom'): # python 2.4 and later
+# Define rand_bytes based on platform.
+try:
+    # Python 2.4 and later have os.urandom,
+    # but it doesn't work on some arches
+    os.urandom(1)
     rand_bytes = os.urandom
-elif sys.platform == 'linux2':
-    rand_bytes = file('/dev/urandom', 'rb').read
-else:
-    # not well seeded, but better than nothing
-    def rand_bytes(n):
-        import random
-        s = ''
-        while n:
-            s += chr(random.randint(0, 255))
-            n -= 1
-        return s
-
+except (NotImplementedError, AttributeError):
+    # If python doesn't have os.urandom, or it doesn't work,
+    # then try to first pull random data from /dev/urandom
+    if os.path.exists("/dev/urandom"):
+        rand_bytes = file('/dev/urandom', 'rb').read
+    # Otherwise, use this hack as a last resort
+    else:
+        # not well seeded, but better than nothing
+        def rand_bytes(n):
+            import random
+            s = ''
+            while n:
+                s += chr(random.randint(0, 255))
+                n -= 1
+            return s
 
 ## TODO: We could later have path objects that remember their list
 ## decomposition (might be too tricksy though.)

